﻿
using Infragistics.Windows;
using Infragistics.Windows.Automation.Peers.DataPresenter;
using Infragistics.Windows.Controls;
using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Automation.Peers;
using System.Windows.Automation.Provider;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Forms;
using System.Windows.Input;
using System.Windows.Markup;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace test
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        bool _refreshRequired = true;
        public MainWindow()
        {
            InitializeComponent();
            xdg.DataContext = GenerateData();
        }

        private DataSet GenerateData()
        {
            var data = new DataSet("SimpleData");
            data.EnforceConstraints = false;

            DataTable parent = new DataTable("Parent");

            parent.Columns.Add("ID", typeof(int));
            parent.Columns.Add("Name", typeof(string));

            parent.PrimaryKey = new[] { parent.Columns[0] };

            DataTable children = new DataTable("Children");

            children.Columns.Add("ID", typeof(int));
            children.Columns.Add("Child", typeof(string));
            children.Columns.Add("Age", typeof(int));
            children.Columns.Add("Parent_ID", typeof(int));

            children.PrimaryKey = new[] { children.Columns[0] };

            data.Tables.Add(parent);
            data.Tables.Add(children);


            data.Relations.Add("Parent_Child", parent.Columns[0], children.Columns[3], false);

            for (int i = 1; i < 4; i++)
            {

                data.Tables["Parent"].Rows.Add(new object[] { i, "Parent" + i });
                for (int j = 0; j < 5; j++)
                {
                    data.Tables["Children"].Rows.Add(new object[] { j, "Child" + j, j + i, i });
                }
            }

            data.AcceptChanges();

            return data;
        }

        private void xdg_FieldLayoutInitialized(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializedEventArgs e)
        {
            if (e.FieldLayout.Key.ToString() == "Parent" || e.FieldLayout.Key.ToString() == "Children")
            {
                e.FieldLayout.Settings.LabelLocation = LabelLocation.Hidden;
            }
        }
    }

    public class ViewModel : INotifyPropertyChanged
    {
        private Timer _timer;


        public ViewModel()
        {
            GridData = new ObservableCollection<Data>();
            GridData = Data.GetData(10, 1, 10);
        }

        private ObservableCollection<Data> _gridData;

        public ObservableCollection<Data> GridData
        {
            get { return _gridData; }
            set
            {
                _gridData = value;
                PropChanged("GridData");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
    public class Data : INotifyPropertyChanged
    {
        private int high;
        private int value;
        private string label;

        public string Label
        {
            get { return label; }
            set
            {
                label = value;
                PropChanged("Label");
            }
        }

        public int High
        {
            get { return high; }
            set
            {
                high = value;
                PropChanged("High");
            }
        }

        public int Value
        {
            get { return value; }
            set
            {
                this.value = value;
                PropChanged("Value");
            }
        }

        public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
        {
            ObservableCollection<Data> data = new ObservableCollection<Data>();
            Random r = new Random();
            for (int i = 0; i < points; i++)
            {
                data.Add(new Data
                {
                    Label = "Item " + r.Next(1,20),
                    High = r.Next(rangeStart, rangeEnd),
                    Value = r.Next(rangeStart, rangeEnd)
                });
            }

            return data;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }


  
        
}
